pub enum DockerActionUses {
Dockerfile,
Image(LoE<DockerUses>),
}Expand description
A uses field for a Docker action step, which can be either a literal ‘Dockerfile’ or a
Docker image (potentially via an expression).
This is essentially a specialization of the common DockerUses type,
since only actions (and not workflows) allow a ‘Dockerfile’ “image”.
Variants
Dockerfile
Image(LoE<DockerUses>)