pub struct Expression(/* private fields */);Expand description
Represents a GitHub Actions expression.
This type performs no syntax checking on the underlying expression,
meaning that it might be invalid. The underlying expression may also
be “curly” or “bare” depending on its origin; use an appropriate
method like Expression::as_curly to access a specific form.
Implementations
sourceimpl Expression
impl Expression
sourcepub fn from_curly(value: String) -> Option<Self>
pub fn from_curly(value: String) -> Option<Self>
Construct an Expression from the given value if and only if
the value is already a “curly” expression.
sourcepub fn from_bare(value: String) -> Option<Self>
pub fn from_bare(value: String) -> Option<Self>
Construct an Expression from the given value if and only if
the value is already a “bare” expression.