Struct github_actions_models::common::Expression

source ·
pub struct Expression(/* private fields */);
Represents a GitHub Actions expression.

This type performs no syntax checking on the underlying expression, meaning that it might be invalid. The underlying expression may also be “curly” or “bare” depending on its origin; use an appropriate method like Expression::as_curly to access a specific form.

Implementations

source

impl Expression

source

pub fn from_curly(value: String) -> Option<Self>

Construct an Expression from the given value if and only if the value is already a “curly” expression.

source

pub fn from_bare(value: String) -> Option<Self>

Construct an Expression from the given value if and only if the value is already a “bare” expression.

source

pub fn as_curly(&self) -> Cow<'_, str>

Returns the “curly” form of this expression, i.e. ${{ expr }}.

source

pub fn as_bare(&self) -> &str

Returns the “bare” form of this expression, i.e. expr if the underlying expression is ${{ expr }}.