pub struct SharedStepFields {
pub id: Option<String>,
pub if: Option<If>,
pub name: Option<String>,
pub timeout_minutes: Option<LoE<f64>>,
pub continue_on_error: BoE,
pub background: bool,
pub env: LoE<Env>,
}Expand description
Fields that are shared across both uses: and run: steps.
Fields
id: Option<String>An optional ID for this step.
if: Option<If>An optional expression that prevents this step from running unless it evaluates to true.
name: Option<String>An optional name for this step.
timeout_minutes: Option<LoE<f64>>An optional timeout for this step, in minutes. GitHub takes the floor of any non-whole numeric value provided.
continue_on_error: BoEAn optional boolean or expression that, if true, prevents the job from failing when
this step fails.
background: boolWhether the step runs asynchronously, i.e. does not block its successor from running.
env: LoE<Env>An optional environment mapping for this step.